@@ -339,7 +339,7 @@ Markov2 <- function(x0, n, x, P){
  mk[1] <- x0
  stato <- which(x==x0)
  for(i in 1:n){
-  mk[i+1] <- sample(x,1,P[stato,],sample=TRUE)
+  mk[i+1] <- sample(x,1, prob=P[stato,], replace=TRUE)
   stato <- which(x==mk[i+1])
  }
  return(list(X=mk,t=0:n))
@@ -366,7 +366,8 @@ lewis <- function(T, lambda, plot.int = TRUE){
 		if(plot.int){
 			plot(E,0:(length(E)-1),type="s",
 				 ylim=c(-1*lambda.range,length(E)))
-			curve(-lambda.range/2+lambda(x),0,T,add=TRUE,
+			g <- function(x) -lambda.range/2+lambda(x)	 
+			curve(g,0,T,add=TRUE,
 				  lty=2,lwd=2)
 		}
 		else
